@@ -65,26 +65,25 @@ class EVENTVIEWS_EXPORT Agenda : public QWidget
 {
     Q_OBJECT
 public:
-    Agenda(AgendaView *agendaView, QScrollArea *scrollArea, int columns, int rows, int rowSize,
-           bool isInteractive);
+    Agenda(AgendaView *agendaView, QScrollArea *scrollArea, int columns, int rows, int rowSize, bool isInteractive);
 
     Agenda(AgendaView *agendaView, QScrollArea *scrollArea, int columns, bool isInteractive);
 
     ~Agenda() override;
 
-    KCalCore::Incidence::Ptr selectedIncidence() const;
-    QDate selectedIncidenceDate() const;
+    Q_REQUIRED_RESULT KCalCore::Incidence::Ptr selectedIncidence() const;
+    Q_REQUIRED_RESULT QDate selectedIncidenceDate() const;
     QSize sizeHint() const override;
     QSize minimumSizeHint() const override;
     QSize minimumSize() const;
     int minimumHeight() const;
     // QSizePolicy sizePolicy() const;
-    int contentsY() const
+    Q_REQUIRED_RESULT int contentsY() const
     {
         return -y();
     }
 
-    int contentsX() const
+    Q_REQUIRED_RESULT int contentsX() const
     {
         return x();
     }
@@ -93,43 +92,38 @@ public:
 
     QScrollArea *scrollArea() const;
 
-    AgendaItem::List agendaItems(const QString &uid) const;
+    Q_REQUIRED_RESULT AgendaItem::List agendaItems(const QString &uid) const;
 
     /**
       Returns the uid of the last incidence that was selected. This
       persists across reloads and clear, so that if the same uid
       reappears, it can be reselected.
     */
-    QString lastSelectedItemUid() const;
+    Q_REQUIRED_RESULT QString lastSelectedItemUid() const;
 
     bool eventFilter(QObject *, QEvent *) override;
 
     void paintEvent(QPaintEvent *) override;
 
-    QPoint contentsToGrid(const QPoint &pos) const;
-    QPoint gridToContents(const QPoint &gpos) const;
+    Q_REQUIRED_RESULT QPoint contentsToGrid(const QPoint &pos) const;
+    Q_REQUIRED_RESULT QPoint gridToContents(const QPoint &gpos) const;
 
-    int timeToY(const QTime &time) const;
-    QTime gyToTime(int y) const;
+    Q_REQUIRED_RESULT int timeToY(const QTime &time) const;
+    Q_REQUIRED_RESULT QTime gyToTime(int y) const;
 
-    QVector<int> minContentsY() const;
-    QVector<int> maxContentsY() const;
+    Q_REQUIRED_RESULT QVector<int> minContentsY() const;
+    Q_REQUIRED_RESULT QVector<int> maxContentsY() const;
 
-    int visibleContentsYMin() const;
-    int visibleContentsYMax() const;
+    Q_REQUIRED_RESULT int visibleContentsYMin() const;
+    Q_REQUIRED_RESULT int visibleContentsYMax() const;
 
     void setStartTime(const QTime &startHour);
 
-    AgendaItem::QPtr insertItem(const KCalCore::Incidence::Ptr &incidence,
-                                const QDateTime &recurrenceId, int X, int YTop, int YBottom,
-                                int itemPos, int itemCount, bool isSelected);
+    AgendaItem::QPtr insertItem(const KCalCore::Incidence::Ptr &incidence, const QDateTime &recurrenceId, int X, int YTop, int YBottom, int itemPos, int itemCount, bool isSelected);
 
-    AgendaItem::QPtr insertAllDayItem(const KCalCore::Incidence::Ptr &event,
-                                      const QDateTime &recurrenceId, int XBegin, int XEnd,
-                                      bool isSelected);
+    AgendaItem::QPtr insertAllDayItem(const KCalCore::Incidence::Ptr &event, const QDateTime &recurrenceId, int XBegin, int XEnd, bool isSelected);
 
-    void insertMultiItem(const KCalCore::Incidence::Ptr &event, const QDateTime &recurrenceId,
-                         int XBegin, int XEnd, int YTop, int YBottom, bool isSelected);
+    void insertMultiItem(const KCalCore::Incidence::Ptr &event, const QDateTime &recurrenceId, int XBegin, int XEnd, int YTop, int YBottom, bool isSelected);
 
     /**
       Removes an event and all its multi-items from the agenda. This function
@@ -142,11 +136,11 @@ public:
 
     void changeColumns(int columns);
 
-    int columns() const;
-    int rows() const;
+    Q_REQUIRED_RESULT int columns() const;
+    Q_REQUIRED_RESULT int rows() const;
 
-    double gridSpacingX() const;
-    double gridSpacingY() const;
+    Q_REQUIRED_RESULT double gridSpacingX() const;
+    Q_REQUIRED_RESULT double gridSpacingY() const;
 
     void clear();
 
@@ -158,7 +152,7 @@ public:
     void setHolidayMask(QVector<bool> *);
 
     void setDateList(const KCalCore::DateList &selectedDates);
-    KCalCore::DateList dateList() const;
+    Q_REQUIRED_RESULT KCalCore::DateList dateList() const;
 
     void setCalendar(const EventViews::MultiViewCalendar::Ptr &cal);
 
@@ -235,8 +229,7 @@ private:
         RESIZERIGHT
     };
 
-    AgendaItem::QPtr createAgendaItem(const KCalCore::Incidence::Ptr &incidence, int itemPos,
-                                      int itemCount, const QDateTime &recurrentId, bool isSelected);
+    AgendaItem::QPtr createAgendaItem(const KCalCore::Incidence::Ptr &incidence, int itemPos, int itemCount, const QDateTime &recurrentId, bool isSelected);
 
 protected:
     /**
@@ -270,8 +263,7 @@ protected:
         @param pos The current mouse position
         @param item The affected item
     */
-    MouseActionType isInResizeArea(bool horizontal, const QPoint &pos,
-                                   const AgendaItem::QPtr &item);
+    MouseActionType isInResizeArea(bool horizontal, const QPoint &pos, const AgendaItem::QPtr &item);
     /** Return whether the cell specified by the grid point belongs to the current select
     */
     bool ptInSelection(const QPoint &gpos) const;
