@@ -31,56 +31,49 @@
 #include "incidencetreemodel.h"
 #include "tododelegates.h"
 #include "todomodel.h"
-#include "todoviewsortfilterproxymodel.h"
 #include "todoviewquickaddline.h"
 #include "todoviewquicksearch.h"
+#include "todoviewsortfilterproxymodel.h"
 #include "todoviewview.h"
-#include "helper.h"
+#include "calendarview_debug.h"
+
+#include <AkonadiCore/EntityMimeTypeFilterModel>
+#include <AkonadiCore/TagFetchJob>
+
+#include <AkonadiWidgets/ETMViewStateSaver>
 
-#include <CalendarSupport/CategoryConfig>
-#include <CalendarSupport/CollectionSelection>
 #include <CalendarSupport/KCalPrefs>
 #include <CalendarSupport/Utils>
 
 #include <Libkdepim/KDatePickerPopup>
 
-#include <entitymimetypefiltermodel.h>
-#include <ETMViewStateSaver>
-#include <TagFetchJob>
-#include <Tag>
-
 #include <KCalCore/CalFormat>
-#include <QIcon>
+
 #include <KIconLoader>
 #include <KJob>
-#include "calendarview_debug.h"
 
-#include <QCheckBox>
 #include <QGridLayout>
 #include <QHeaderView>
 #include <QMenu>
 #include <QToolButton>
-#include <QItemSelection>
-#include <QTimer>
 
 Q_DECLARE_METATYPE(QPointer<QMenu>)
 
 using namespace EventViews;
 using namespace KCalCore;
 
-namespace EventViews
-{
+namespace EventViews {
 // We share this struct between all views, for performance and memory purposes
 class ModelStack
 {
 public:
     ModelStack(const EventViews::PrefsPtr &preferences, QObject *parent_)
-        : todoModel(new TodoModel(preferences)),
-          parent(parent_),
-          calendar(nullptr),
-          todoTreeModel(nullptr),
-          todoFlatModel(nullptr),
-          prefs(preferences)
+        : todoModel(new TodoModel(preferences))
+        , parent(parent_)
+        , calendar(nullptr)
+        , todoTreeModel(nullptr)
+        , todoFlatModel(nullptr)
+        , prefs(preferences)
     {
     }
 
@@ -108,7 +101,7 @@ public:
             foreach (TodoView *view, views) {
                 // In flatview dropping confuses users and it's very easy to drop into a child item
                 view->mView->setDragDropMode(QAbstractItemView::DragOnly);
-                view->setFlatView(flat, /**propagate=*/false);   // So other views update their toggle icon
+                view->setFlatView(flat, /**propagate=*/ false);   // So other views update their toggle icon
 
                 if (todoTreeModel) {
                     view->saveViewState(); // Save the tree state before it's gone
@@ -127,10 +120,12 @@ public:
             delete todoTreeModel;
             todoTreeModel = new IncidenceTreeModel(QStringList() << todoMimeType, parent);
             foreach (TodoView *view, views) {
-                QObject::connect(todoTreeModel, &IncidenceTreeModel::indexChangedParent, view, &TodoView::expandIndex);
-                QObject::connect(todoTreeModel, &IncidenceTreeModel::batchInsertionFinished, view, &TodoView::restoreViewState);
+                QObject::connect(todoTreeModel, &IncidenceTreeModel::indexChangedParent, view,
+                                 &TodoView::expandIndex);
+                QObject::connect(todoTreeModel, &IncidenceTreeModel::batchInsertionFinished, view,
+                                 &TodoView::restoreViewState);
                 view->mView->setDragDropMode(QAbstractItemView::DragDrop);
-                view->setFlatView(flat, /**propagate=*/false);   // So other views update their toggle icon
+                view->setFlatView(flat, /**propagate=*/ false);   // So other views update their toggle icon
             }
             todoTreeModel->setSourceModel(calendar ? calendar->model() : nullptr);
             todoModel->setSourceModel(todoTreeModel);
@@ -165,13 +160,13 @@ public:
         return todoFlatModel != nullptr;
     }
 
-    TodoModel *todoModel;
+    TodoModel *todoModel = nullptr;
     QList<TodoView *> views;
-    QObject *parent;
+    QObject *parent = nullptr;
 
     Akonadi::ETMCalendar::Ptr calendar;
-    IncidenceTreeModel *todoTreeModel;
-    Akonadi::EntityMimeTypeFilterModel *todoFlatModel;
+    IncidenceTreeModel *todoTreeModel = nullptr;
+    Akonadi::EntityMimeTypeFilterModel *todoFlatModel = nullptr;
     EventViews::PrefsPtr prefs;
 };
 }
@@ -179,8 +174,7 @@ public:
 // Don't use K_GLOBAL_STATIC, see QTBUG-22667
 static ModelStack *sModels = nullptr;
 
-TodoView::TodoView(const EventViews::PrefsPtr &prefs,
-                   bool sidebarView, QWidget *parent)
+TodoView::TodoView(const EventViews::PrefsPtr &prefs, bool sidebarView, QWidget *parent)
     : EventView(parent)
     , mQuickSearch(nullptr)
     , mQuickAdd(nullptr)
@@ -205,18 +199,24 @@ TodoView::TodoView(const EventViews::PrefsPtr &prefs,
     mProxyModel->setFilterKeyColumn(TodoModel::SummaryColumn);
     mProxyModel->setFilterCaseSensitivity(Qt::CaseInsensitive);
     mProxyModel->setSortRole(Qt::EditRole);
-    connect(mProxyModel, &TodoViewSortFilterProxyModel::rowsInserted, this, &TodoView::onRowsInserted);
+    connect(mProxyModel, &TodoViewSortFilterProxyModel::rowsInserted, this,
+            &TodoView::onRowsInserted);
 
     if (!mSidebarView) {
         mQuickSearch = new TodoViewQuickSearch(calendar(), this);
         mQuickSearch->setVisible(prefs->enableTodoQuickSearch());
         connect(mQuickSearch, SIGNAL(searchTextChanged(QString)),
                 mProxyModel, SLOT(setFilterRegExp(QString)));
-        connect(mQuickSearch, &TodoViewQuickSearch::searchTextChanged, this, &TodoView::restoreViewState);
-        connect(mQuickSearch, &TodoViewQuickSearch::filterCategoryChanged, mProxyModel, &TodoViewSortFilterProxyModel::setCategoryFilter);
-        connect(mQuickSearch, &TodoViewQuickSearch::filterCategoryChanged, this, &TodoView::restoreViewState);
-        connect(mQuickSearch, &TodoViewQuickSearch::filterPriorityChanged, mProxyModel, &TodoViewSortFilterProxyModel::setPriorityFilter);
-        connect(mQuickSearch, &TodoViewQuickSearch::filterPriorityChanged, this, &TodoView::restoreViewState);
+        connect(mQuickSearch, &TodoViewQuickSearch::searchTextChanged, this,
+                &TodoView::restoreViewState);
+        connect(mQuickSearch, &TodoViewQuickSearch::filterCategoryChanged, mProxyModel,
+                &TodoViewSortFilterProxyModel::setCategoryFilter);
+        connect(mQuickSearch, &TodoViewQuickSearch::filterCategoryChanged, this,
+                &TodoView::restoreViewState);
+        connect(mQuickSearch, &TodoViewQuickSearch::filterPriorityChanged, mProxyModel,
+                &TodoViewSortFilterProxyModel::setPriorityFilter);
+        connect(mQuickSearch, &TodoViewQuickSearch::filterPriorityChanged, this,
+                &TodoView::restoreViewState);
     }
 
     mView = new TodoViewView(this);
@@ -230,11 +230,12 @@ TodoView::TodoView(const EventViews::PrefsPtr &prefs,
     mView->setDragDropMode(QAbstractItemView::DragDrop);
 
     mView->setExpandsOnDoubleClick(false);
-    mView->setEditTriggers(QAbstractItemView::SelectedClicked |
-                           QAbstractItemView::EditKeyPressed);
+    mView->setEditTriggers(QAbstractItemView::SelectedClicked | QAbstractItemView::EditKeyPressed);
 
-    connect(mView->header(), &QHeaderView::geometriesChanged, this, &TodoView::scheduleResizeColumns);
-    connect(mView, &TodoViewView::visibleColumnCountChanged, this, &TodoView::resizeColumns);
+    connect(mView->header(), &QHeaderView::geometriesChanged,
+            this, &TodoView::scheduleResizeColumns);
+    connect(mView, &TodoViewView::visibleColumnCountChanged,
+            this, &TodoView::resizeColumns);
 
     TodoRichTextDelegate *richTextDelegate = new TodoRichTextDelegate(mView);
     mView->setItemDelegateForColumn(TodoModel::SummaryColumn, richTextDelegate);
@@ -258,7 +259,9 @@ TodoView::TodoView(const EventViews::PrefsPtr &prefs,
     connect(mView, &TodoViewView::customContextMenuRequested, this, &TodoView::contextMenu);
     connect(mView, &TodoViewView::doubleClicked, this, &TodoView::itemDoubleClicked);
 
-    connect(mView->selectionModel(), &QItemSelectionModel::selectionChanged, this, &TodoView::selectionChanged);
+    connect(
+        mView->selectionModel(), &QItemSelectionModel::selectionChanged, this,
+        &TodoView::selectionChanged);
 
     mQuickAdd = new TodoViewQuickAddLine(this);
     mQuickAdd->setClearButtonEnabled(true);
@@ -308,7 +311,7 @@ TodoView::TodoView(const EventViews::PrefsPtr &prefs,
     // Dummy layout just to add a few px of right margin so the checkbox is aligned
     // with the QAbstractItemView's viewport.
     QHBoxLayout *dummyLayout = new QHBoxLayout();
-    dummyLayout->setContentsMargins(0, 0, mView->frameWidth()/*right*/, 0);
+    dummyLayout->setContentsMargins(0, 0, mView->frameWidth() /*right*/, 0);
     if (!mSidebarView) {
         QFrame *f = new QFrame(this);
         f->setFrameShape(QFrame::VLine);
@@ -319,36 +322,36 @@ TodoView::TodoView(const EventViews::PrefsPtr &prefs,
     dummyLayout->addWidget(mFlatViewButton);
 
     layout->addLayout(dummyLayout, 2, 1);
-    setLayout(layout);
 
     // ---------------- POPUP-MENUS -----------------------
     mItemPopupMenu = new QMenu(this);
 
     mItemPopupMenuItemOnlyEntries << mItemPopupMenu->addAction(
-                                      i18nc("@action:inmenu show the to-do", "&Show"),
-                                      this, SLOT(showTodo()));
+        i18nc("@action:inmenu show the to-do", "&Show"),
+        this, SLOT(showTodo()));
 
     QAction *a = mItemPopupMenu->addAction(
-                     i18nc("@action:inmenu edit the to-do", "&Edit..."),
-                     this, SLOT(editTodo()));
+        i18nc("@action:inmenu edit the to-do", "&Edit..."),
+        this, &TodoView::editTodo);
     mItemPopupMenuReadWriteEntries << a;
     mItemPopupMenuItemOnlyEntries << a;
 
     mItemPopupMenu->addSeparator();
     mItemPopupMenuItemOnlyEntries << mItemPopupMenu->addAction(
-                                      QIcon::fromTheme(QStringLiteral("document-print")),
-                                      i18nc("@action:inmenu print the to-do", "&Print..."),
-                                      this, SIGNAL(printTodo()));
+        QIcon::fromTheme(QStringLiteral("document-print")),
+        i18nc("@action:inmenu print the to-do", "&Print..."),
+        this, &TodoView::printTodo);
 
     mItemPopupMenuItemOnlyEntries << mItemPopupMenu->addAction(
-                                      QIcon::fromTheme(QStringLiteral("document-print-preview")),
-                                      i18nc("@action:inmenu print preview the to-do", "Print Previe&w..."),
-                                      this, SIGNAL(printPreviewTodo()));
+        QIcon::fromTheme(QStringLiteral("document-print-preview")),
+        i18nc("@action:inmenu print preview the to-do", "Print Previe&w..."),
+        this, SIGNAL(printPreviewTodo()));
     mItemPopupMenu->addSeparator();
     a = mItemPopupMenu->addAction(
-            KIconLoader::global()->loadIcon(QStringLiteral("edit-delete"), KIconLoader::NoGroup, KIconLoader::SizeSmall),
-            i18nc("@action:inmenu delete the to-do", "&Delete"),
-            this, SLOT(deleteTodo()));
+        KIconLoader::global()->loadIcon(QStringLiteral("edit-delete"), KIconLoader::NoGroup,
+                                        KIconLoader::SizeSmall),
+        i18nc("@action:inmenu delete the to-do", "&Delete"),
+        this, SLOT(deleteTodo()));
     mItemPopupMenuReadWriteEntries << a;
     mItemPopupMenuItemOnlyEntries << a;
 
@@ -361,19 +364,19 @@ TodoView::TodoView(const EventViews::PrefsPtr &prefs,
         this, SLOT(newTodo()));
 
     a = mItemPopupMenu->addAction(
-            i18nc("@action:inmenu create a new sub-to-do", "New Su&b-to-do..."),
-            this, SLOT(newSubTodo()));
+        i18nc("@action:inmenu create a new sub-to-do", "New Su&b-to-do..."),
+        this, SLOT(newSubTodo()));
     mItemPopupMenuReadWriteEntries << a;
     mItemPopupMenuItemOnlyEntries << a;
 
     mMakeTodoIndependent = mItemPopupMenu->addAction(
-                               i18nc("@action:inmenu", "&Make this To-do Independent"),
-                               this, SIGNAL(unSubTodoSignal()));
+        i18nc("@action:inmenu", "&Make this To-do Independent"),
+        this, SIGNAL(unSubTodoSignal()));
 
-    mMakeSubtodosIndependent =
-        mItemPopupMenu->addAction(
-            i18nc("@action:inmenu", "Make all Sub-to-dos &Independent"),
-            this, SIGNAL(unAllSubTodoSignal()));
+    mMakeSubtodosIndependent
+        = mItemPopupMenu->addAction(
+              i18nc("@action:inmenu", "Make all Sub-to-dos &Independent"),
+              this, SIGNAL(unAllSubTodoSignal()));
 
     mItemPopupMenuItemOnlyEntries << mMakeTodoIndependent;
     mItemPopupMenuItemOnlyEntries << mMakeSubtodosIndependent;
@@ -383,15 +386,19 @@ TodoView::TodoView(const EventViews::PrefsPtr &prefs,
 
     mItemPopupMenu->addSeparator();
 
-    a = mItemPopupMenu->addAction(KIconLoader::global()->loadIcon(QStringLiteral("appointment-new"), KIconLoader::NoGroup, KIconLoader::SizeSmall),
-                                  i18n("Create Event"),
+    a = mItemPopupMenu->addAction(KIconLoader::global()->loadIcon(QStringLiteral("appointment-new"),
+                                                                  KIconLoader::NoGroup,
+                                                                  KIconLoader::SizeSmall),
+                                  i18nc("@action:inmenu", "Create Event"),
                                   this, SLOT(createEvent()));
     a->setObjectName(QStringLiteral("createevent"));
     mItemPopupMenuReadWriteEntries << a;
     mItemPopupMenuItemOnlyEntries << a;
 
-    a = mItemPopupMenu->addAction(KIconLoader::global()->loadIcon(QStringLiteral("view-pim-notes"), KIconLoader::NoGroup, KIconLoader::SizeSmall),
-                                  i18n("Create Note"),
+    a = mItemPopupMenu->addAction(KIconLoader::global()->loadIcon(QStringLiteral("view-pim-notes"),
+                                                                  KIconLoader::NoGroup,
+                                                                  KIconLoader::SizeSmall),
+                                  i18nc("@action:inmenu", "Create Note"),
                                   this, SLOT(createNote()));
     a->setObjectName(QStringLiteral("createnote"));
     mItemPopupMenuReadWriteEntries << a;
@@ -399,22 +406,20 @@ TodoView::TodoView(const EventViews::PrefsPtr &prefs,
 
     mItemPopupMenu->addSeparator();
 
-    mCopyPopupMenu =
-        new KPIM::KDatePickerPopup(KPIM::KDatePickerPopup::NoDate |
-                                   KPIM::KDatePickerPopup::DatePicker |
-                                   KPIM::KDatePickerPopup::Words,
-                                   QDate::currentDate(), this);
+    mCopyPopupMenu = new KPIM::KDatePickerPopup(KPIM::KDatePickerPopup::NoDate
+                                                |KPIM::KDatePickerPopup::DatePicker
+                                                |KPIM::KDatePickerPopup::Words,
+                                                QDate::currentDate(), this);
     mCopyPopupMenu->setTitle(i18nc("@title:menu", "&Copy To"));
 
     connect(mCopyPopupMenu, &KPIM::KDatePickerPopup::dateChanged, this, &TodoView::copyTodoToDate);
 
     connect(mCopyPopupMenu, &KPIM::KDatePickerPopup::dateChanged, mItemPopupMenu, &QMenu::hide);
 
-    mMovePopupMenu =
-        new KPIM:: KDatePickerPopup(KPIM::KDatePickerPopup::NoDate |
-                                    KPIM::KDatePickerPopup::DatePicker |
-                                    KPIM::KDatePickerPopup::Words,
-                                    QDate::currentDate(), this);
+    mMovePopupMenu = new KPIM:: KDatePickerPopup(KPIM::KDatePickerPopup::NoDate
+                                                 |KPIM::KDatePickerPopup::DatePicker
+                                                 |KPIM::KDatePickerPopup::Words,
+                                                 QDate::currentDate(), this);
     mMovePopupMenu->setTitle(i18nc("@title:menu", "&Move To"));
 
     connect(mMovePopupMenu, &KPIM::KDatePickerPopup::dateChanged, this, &TodoView::setNewDate);
@@ -581,14 +586,13 @@ void TodoView::restoreLayout(KConfig *config, const QString &group, bool minimal
 
         // We don't have any incidences (content) yet, so we delay resizing
         QTimer::singleShot(0, this, &TodoView::resizeColumns);
-
     } else {
         for (int i = 0;
-                i < header->count() &&
-                i < columnOrder.size() &&
-                i < columnWidths.size() &&
-                i < columnVisibility.size();
-                i++) {
+             i < header->count()
+             && i < columnOrder.size()
+             && i < columnWidths.size()
+             && i < columnVisibility.size();
+             i++) {
             bool visible = columnVisibility[i].toBool();
             int width = columnWidths[i].toInt();
             int order = columnOrder[i].toInt();
@@ -658,9 +662,7 @@ void TodoView::clearSelection()
     mView->selectionModel()->clearSelection();
 }
 
-void TodoView::addTodo(const QString &summary,
-                       const Akonadi::Item &parentItem,
-                       const QStringList &categories)
+void TodoView::addTodo(const QString &summary, const Akonadi::Item &parentItem, const QStringList &categories)
 {
     const QString summaryTrimmed = summary.trimmed();
     if (!changer() || summaryTrimmed.isEmpty()) {
@@ -695,9 +697,9 @@ void TodoView::addTodo(const QString &summary,
 void TodoView::addQuickTodo(Qt::KeyboardModifiers modifiers)
 {
     if (modifiers == Qt::NoModifier) {
-        /*const QModelIndex index = */ addTodo(mQuickAdd->text(), Akonadi::Item(),
-                                               mProxyModel->categories());
-
+        /*const QModelIndex index = */
+        addTodo(mQuickAdd->text(), Akonadi::Item(),
+                mProxyModel->categories());
     } else if (modifiers == Qt::ControlModifier) {
         QModelIndexList selection = mView->selectionModel()->selectedRows();
         if (selection.count() != 1) {
@@ -707,7 +709,8 @@ void TodoView::addQuickTodo(Qt::KeyboardModifiers modifiers)
         const QModelIndex idx = mProxyModel->mapToSource(selection[0]);
         mView->expand(selection[0]);
         const Akonadi::Item parent = sModels->todoModel->data(idx,
-                                     Akonadi::EntityTreeModel::ItemRole).value<Akonadi::Item>();
+                                                              Akonadi::EntityTreeModel::ItemRole).
+                                     value<Akonadi::Item>();
         addTodo(mQuickAdd->text(), parent, mProxyModel->categories());
     } else {
         return;
@@ -720,7 +723,7 @@ void TodoView::contextMenu(const QPoint &pos)
     const bool hasItem = mView->indexAt(pos).isValid();
     Incidence::Ptr incidencePtr;
 
-    Q_FOREACH (QAction *entry, mItemPopupMenuItemOnlyEntries) {
+    for (QAction *entry : qAsConst(mItemPopupMenuItemOnlyEntries)) {
         bool enable;
 
         if (hasItem) {
@@ -735,11 +738,10 @@ void TodoView::contextMenu(const QPoint &pos)
                 // Action isn't RO, it can change the incidence, "Edit" for example.
                 const bool actionIsRw = mItemPopupMenuReadWriteEntries.contains(entry);
 
-                const bool incidenceIsRO = !calendar()->hasRight(item, Akonadi::Collection::CanChangeItem);
-
-                enable = hasItem && (!actionIsRw ||
-                                     !incidenceIsRO);
+                const bool incidenceIsRO = !calendar()->hasRight(item,
+                                                                 Akonadi::Collection::CanChangeItem);
 
+                enable = hasItem && (!actionIsRw || !incidenceIsRO);
             }
         } else {
             enable = false;
@@ -754,7 +756,8 @@ void TodoView::contextMenu(const QPoint &pos)
         if (incidencePtr) {
             const bool hasRecId = incidencePtr->hasRecurrenceId();
             if (calendar()) {
-                mMakeSubtodosIndependent->setEnabled(!hasRecId && !calendar()->childItems(incidencePtr->uid()).isEmpty());
+                mMakeSubtodosIndependent->setEnabled(
+                    !hasRecId && !calendar()->childItems(incidencePtr->uid()).isEmpty());
             }
             mMakeTodoIndependent->setEnabled(!hasRecId && !incidencePtr->relatedTo().isEmpty());
         }
@@ -782,8 +785,7 @@ void TodoView::contextMenu(const QPoint &pos)
     }
 }
 
-void TodoView::selectionChanged(const QItemSelection &selected,
-                                const QItemSelection &deselected)
+void TodoView::selectionChanged(const QItemSelection &selected, const QItemSelection &deselected)
 {
     Q_UNUSED(deselected);
     QModelIndexList selection = selected.indexes();
@@ -828,8 +830,8 @@ void TodoView::deleteTodo()
 {
     QModelIndexList selection = mView->selectionModel()->selectedRows();
     if (selection.size() == 1) {
-        const Akonadi::Item todoItem =
-            selection[0].data(TodoModel::TodoRole).value<Akonadi::Item>();
+        const Akonadi::Item todoItem
+            = selection[0].data(TodoModel::TodoRole).value<Akonadi::Item>();
 
         if (!changer()->deletedRecently(todoItem.id())) {
             Q_EMIT deleteIncidenceSignal(todoItem);
@@ -846,8 +848,8 @@ void TodoView::newSubTodo()
 {
     QModelIndexList selection = mView->selectionModel()->selectedRows();
     if (selection.size() == 1) {
-        const Akonadi::Item todoItem =
-            selection[0].data(TodoModel::TodoRole).value<Akonadi::Item>();
+        const Akonadi::Item todoItem
+            = selection[0].data(TodoModel::TodoRole).value<Akonadi::Item>();
 
         Q_EMIT newSubTodoSignal(todoItem);
     } else {
@@ -870,9 +872,9 @@ void TodoView::copyTodoToDate(const QDate &date)
     const QModelIndex origIndex = mProxyModel->mapToSource(selection[0]);
     Q_ASSERT(origIndex.isValid());
 
-    const Akonadi::Item origItem =
-        sModels->todoModel->data(origIndex,
-                                 Akonadi::EntityTreeModel::ItemRole).value<Akonadi::Item>();
+    const Akonadi::Item origItem
+        = sModels->todoModel->data(origIndex,
+                                   Akonadi::EntityTreeModel::ItemRole).value<Akonadi::Item>();
 
     const KCalCore::Todo::Ptr orig = CalendarSupport::todo(origItem);
     if (!orig) {
@@ -883,7 +885,7 @@ void TodoView::copyTodoToDate(const QDate &date)
 
     todo->setUid(KCalCore::CalFormat::createUniqueId());
 
-    KDateTime due = todo->dtDue();
+    QDateTime due = todo->dtDue();
     due.setDate(date);
     todo->setDtDue(due);
 
@@ -969,7 +971,7 @@ void TodoView::setNewDate(const QDate &date)
     if (calendar()->hasRight(todoItem, Akonadi::Collection::CanChangeItem)) {
         KCalCore::Todo::Ptr oldTodo(todo->clone());
 
-        KDateTime dt(date);
+        QDateTime dt(date);
 
         if (!todo->allDay()) {
             dt.setTime(todo->dtDue().time());
@@ -999,7 +1001,7 @@ void TodoView::setNewPercentage(QAction *action)
 
         int percentage = mPercentage.value(action);
         if (percentage == 100) {
-            todo->setCompleted(KDateTime::currentLocalDateTime());
+            todo->setCompleted(QDateTime::currentDateTime());
             todo->setPercentComplete(100);
         } else {
             todo->setPercentComplete(percentage);
@@ -1115,7 +1117,8 @@ void TodoView::onRowsInserted(const QModelIndex &parent, int start, int end)
         return;
     }
 
-    const bool isPopulated = calendar()->entityTreeModel()->isCollectionPopulated(item.storageCollectionId());
+    const bool isPopulated = calendar()->entityTreeModel()->isCollectionPopulated(
+        item.storageCollectionId());
     if (!isPopulated) {
         return;
     }
@@ -1127,9 +1130,9 @@ void TodoView::onRowsInserted(const QModelIndex &parent, int start, int end)
             // don't destroy complex selections, not applicable now (only single
             // selection allowed), but for the future...
             int colCount = static_cast<int>(TodoModel::ColumnCount);
-            mView->selectionModel()->select(QItemSelection(idx, mView->model()->index(start, colCount - 1)),
-                                            QItemSelectionModel::ClearAndSelect |
-                                            QItemSelectionModel::Rows);
+            mView->selectionModel()->select(
+                QItemSelection(idx, mView->model()->index(start, colCount - 1)),
+                QItemSelectionModel::ClearAndSelect | QItemSelectionModel::Rows);
         }
         return;
     }
@@ -1147,12 +1150,10 @@ void TodoView::onRowsInserted(const QModelIndex &parent, int start, int end)
     }
 }
 
-void TodoView::getHighlightMode(bool &highlightEvents,
-                                bool &highlightTodos,
-                                bool &highlightJournals)
+void TodoView::getHighlightMode(bool &highlightEvents, bool &highlightTodos, bool &highlightJournals)
 {
-    highlightTodos    = preferences()->highlightTodos();
-    highlightEvents   = !highlightTodos;
+    highlightTodos = preferences()->highlightTodos();
+    highlightEvents = !highlightTodos;
     highlightJournals = false;
 }
 
@@ -1175,12 +1176,15 @@ void TodoView::resizeColumns()
     // We have 3 columns that should stretch: summary, description and categories.
     // Summary is always visible.
     const bool descriptionVisible = !mView->isColumnHidden(TodoModel::DescriptionColumn);
-    const bool categoriesVisible  = !mView->isColumnHidden(TodoModel::CategoriesColumn);
+    const bool categoriesVisible = !mView->isColumnHidden(TodoModel::CategoriesColumn);
 
     // Calculate size of non-stretchable columns:
     int size = 0;
     for (int i = 0; i < TodoModel::ColumnCount; ++i) {
-        if (!mView->isColumnHidden(i) && i != TodoModel::SummaryColumn && i != TodoModel::DescriptionColumn && i != TodoModel::CategoriesColumn) {
+        if (!mView->isColumnHidden(i)
+            && i != TodoModel::SummaryColumn
+            && i != TodoModel::DescriptionColumn
+            && i != TodoModel::CategoriesColumn) {
             size += mView->columnWidth(i);
         }
     }
@@ -1198,7 +1202,7 @@ void TodoView::resizeColumns()
     }
 
     if (remainingSize < requiredSize) {
-        // We have too little size (that's what she...), so lets use an horizontal scrollbar and make these columns use whatever they need.
+        // Too little size, so let's use a horizontal scrollbar
         mView->resizeColumnToContents(TodoModel::SummaryColumn);
         mView->resizeColumnToContents(TodoModel::DescriptionColumn);
     } else if (descriptionVisible) {
